==> xlniux-client-1.0.1-20141016.100933-1-sources.jar: com/xunlei/niux/client/xlshop/ShopReleaseGoodClient.java <==
package com.xunlei.niux.client.xlshop;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.MapEasyUtils;
import com.xunlei.niux.client.util.RBundleUtil;
import com.xunlei.niux.client.util.SignUtil;
import com.xunlei.util.Log;
import org.slf4j.Logger;

import java.util.HashMap;
import java.util.Map;
import java.util.ResourceBundle;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class ShopReleaseGoodClient {
    private static final Logger logger = Log.getLogger(ShopReleaseGoodClient.class);
    private static final String xlSHopURL = RBundleUtil.getString("niuxclient","xlshop_url","");
    private static final String priKey = RBundleUtil.getString("niuxclient","xlshop_priKey","");

    private static final String bizName = "niux";

    public static Map<String,Object> takeOrder(String userId,int goodId,String orderId,int addressId){
        String url = xlSHopURL;

        Map param = new HashMap();
        param.put("controller","autobuy");
        param.put("action","takeorder");
        param.put("user_id",userId);
        param.put("goods_id",String.valueOf(goodId));
        param.put("order_id", orderId);
        param.put("address_id",String.valueOf(addressId));
        String sign = SignUtil.sign(param,priKey);
        param.put("sign",sign);
        param.put("bizname",bizName);
        url += SignUtil.getSignatureContent(param);

        logger.info("{} takeOrder request url: {}",goodId,url);
        String resp = HttpClientUtil.get(url);
        logger.info("{} takeOrder response result: {}",goodId,resp);

        if(resp.contains("ret=0")){
            return MapEasyUtils.generateMap(0,resp);
        }

        return MapEasyUtils.generateMap(1,resp);
    }
}

==> xlniux-client-1.0.7-20150331.084510-5-sources.jar: com/xunlei/niux/client/xlshop/ShopReleaseGoodClient.java <==
package com.xunlei.niux.client.xlshop;

import com.xunlei.niux.client.util.HttpClientUtil;
import com.xunlei.niux.client.util.MapEasyUtils;
import com.xunlei.niux.client.util.SignUtil;
import com.xunlei.niux.easyutils.propertyutils.EnvPropertyUtil;
import com.xunlei.util.Log;
import org.slf4j.Logger;

import java.util.HashMap;
import java.util.Map;

/**
 * Created by jamesjxin on 14-4-17.
 */
public class ShopReleaseGoodClient {
    private static final Logger logger = Log.getLogger(ShopReleaseGoodClient.class);
    private static final String xlSHopURL = EnvPropertyUtil.loadProperty("niuxclient", "xlshop_url", "");
    private static final String priKey = EnvPropertyUtil.loadProperty("niuxclient","xlshop_priKey","");

    private static final String bizName = "niux";

    public static Map<String,Object> takeOrder(String userId,int goodId,String orderId,int addressId){
        String url = xlSHopURL;

        Map param = new HashMap();
        param.put("controller","autobuy");
        param.put("action","takeorder");
        param.put("user_id",userId);
        param.put("goods_id",String.valueOf(goodId));
        param.put("order_id", orderId);
        param.put("address_id",String.valueOf(addressId));
        String sign = SignUtil.sign(param,priKey);
        param.put("sign",sign);
        param.put("bizname",bizName);
        url += SignUtil.getSignatureContent(param);

        logger.info("{} takeOrder request url: {}",goodId,url);
        String resp = HttpClientUtil.get(url);
        logger.info("{} takeOrder response result: {}",goodId,resp);

        if(resp.contains("ret=0")){
            return MapEasyUtils.generateMap(0,resp);
        }

        return MapEasyUtils.generateMap(1,resp);
    }
}
